summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2010-04-24 12:55:36 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2010-04-24 13:05:38 -0500
commit1ebd001fb459552c4678c0b5cb6baa80d65ab6b5 (patch)
tree8b3da414242200aaf137f17ac992c361d06c438f /png.h
parent18b897da9c616c208a051af6b7fd8d2404d64daf (diff)
downloadlibpng-1ebd001fb459552c4678c0b5cb6baa80d65ab6b5.tar.gz
[devel] Bump back to version libpng-1.5.0beta20
Diffstat (limited to 'png.h')
-rw-r--r--png.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/png.h b/png.h
index c0fc5d31b..5d4b078bc 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.0beta19 - April 24, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.0beta19 - April 24, 2010: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -170,7 +170,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.0beta19, April 24, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -288,7 +288,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.0beta19 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -344,9 +344,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.0beta19"
+#define PNG_LIBPNG_VER_STRING "1.5.0beta20"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.0beta19 - April 24, 2010\n"
+ " libpng version 1.5.0beta20 - April 24, 2010\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -359,7 +359,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 19
+#define PNG_LIBPNG_VER_BUILD 20
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -834,7 +834,7 @@ typedef PNG_CALLBACK(void, *png_free_ptr, (png_structp, png_voidp),);
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_5_0beta19;
+typedef png_structp version_1_5_0beta20;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.0beta19 - April 24, 2010
+ * libpng version 1.5.0beta20 - April 24, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.0beta19 - April 24, 2010: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.0beta20 - April 24, 2010: Glenn
* See also "Contributing Authors", below.
*
@@ -170,7 +170,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta19, April 24, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta20, April 24, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -288,7 +288,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.0beta19 are Y2K compliant. It is my belief that earlier
+ * upward through 1.5.0beta20 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*